@@ -5,11 +5,16 @@
 ///
 #include "widget/dialogwrap.h"
 
-class About_Dialog : public DialogWrap {
+/**
+ * This is a singleton.
+ */
+class AboutDialog : public DialogWrap {
 public:
-  About_Dialog();
+  AboutDialog();
+  static AboutDialog &instance();
 private:
   void on_response(int);
+  static AboutDialog *_instance;
 };
 
 #endif
