@@ -13,27 +13,31 @@
 #include <gtkmm/stock.h>
 #include <gtkmm/image.h>
 
-#include <util/warning.h>
+#include "util/warning.h"
 
-#include "globals.h"
-#include "safeslot.h"
-#include "paper_sizes.h"
-#include "document.h"
+#include "document/paper_sizes.h"
+#include "document/document.h"
 #include "window.h"
-#include "errordialog.h"
-#include "fileerrors.h"
 #include "config.h"
 
 #include "widget/filesel.h"
 #include "widget/spinner.h"
 #include "widget/wmisc.h"
+#include "widget/usererror.h"
 
-Doc_Props_Dialog::Doc_Props_Dialog():
+DocPropsDialog *DocPropsDialog::_instance = 0;
+
+DocPropsDialog &DocPropsDialog::instance() {
+  if(!_instance)
+    _instance = new DocPropsDialog();
+  return *_instance;
+}
+
+DocPropsDialog::DocPropsDialog():
   DialogWrap(""), // don't know title or parent
   view(0)
 {
   template_button = manage(new Gtk::CheckButton("_Use template:", true));
-
   portrait_button = manage(new Gtk::RadioButton("_Portrait", true));
   landscape_button = manage(new Gtk::RadioButton("_Landscape", true));
 
@@ -41,8 +45,8 @@ Doc_Props_Dialog::Doc_Props_Dialog():
   double_sided_button = manage(new Gtk::RadioButton("_Double-sided", true));
 
   paper_size = manage(new Gtk::Combo());
-  file_entry = manage(new File_Entry("Select template"));
-  first_page = manage(new Spinner(1, false));
+  file_entry = manage(new FileEntry("Select template"));
+  first_page = manage(new Spinner(config.StartPage.values.front(), false));
 
   Gtk::HBox *template_box = manage(new Gtk::HBox(false, double_space));
   Gtk::VBox *sidedness_box = manage(new Gtk::VBox(false, single_space)),
@@ -59,23 +63,20 @@ Doc_Props_Dialog::Doc_Props_Dialog():
     std::string& default_paper = config.PaperName.values.front();
     bool default_is_known = false;
     std::list<std::string> paper_list;
-    for(std::map<std::string, Papers::Size>::const_iterator i 
-	  = papers.sizes.begin();
-	i!=papers.sizes.end();
-	i++) {
+    for(std::map<std::string, Papers::Size>::const_iterator 
+	  i = papers.sizes.begin(); i!=papers.sizes.end(); i++) {
       paper_list.push_back(i->first);
       if(i->first == default_paper)
 	default_is_known = true;
     }
     paper_size->set_popdown_strings(paper_list);
-    if(!default_is_known)
-      {
-	warning << "Paper type \"" << default_paper 
-		<< "\" is unknown." << std::endl;
-	default_paper = "A4";
-	config.PaperName.values.clear();
-	config.PaperName.values.push_back(default_paper);
-      }
+    if(!default_is_known) {
+      warning << "Paper type \"" << default_paper 
+	      << "\" is unknown." << std::endl;
+      default_paper = "A4";
+      config.PaperName.values.clear();
+      config.PaperName.values.push_back(default_paper);
+    }
     paper_size->get_entry()->set_text(default_paper);
   }
 
@@ -114,7 +115,7 @@ Doc_Props_Dialog::Doc_Props_Dialog():
 
   first_page_box->pack_end(*first_page, Gtk::PACK_SHRINK);
   Gtk::Label *first_page_label = 
-    manage(new Gtk::Label("First page _number:", true));
+    manage(new Gtk::Label("First page nu_mber:", true));
   first_page_label->set_mnemonic_widget(first_page->get_spinbutton());
   first_page_box->pack_end(*first_page_label, 
 			   Gtk::PACK_SHRINK);
@@ -128,34 +129,39 @@ Doc_Props_Dialog::Doc_Props_Dialog():
   get_vbox()->pack_start(*vbox);
 
   template_button->set_active(true);
+  file_entry->entry.set_text(config.DocTemplatePath.values.front());
   portrait_button->set_active(!config.Landscape.values.front());
-  double_sided_button->set_active(true);
+  config.SingleSided.values.front() ?
+    single_sided_button->set_active() :
+    double_sided_button->set_active();
 
   paper_size->get_entry()->set_editable(false);
 
-  add_button(Gtk::Stock::CANCEL, 0);
+  cancel_button = add_button(Gtk::Stock::CANCEL, 0);
   ok_button = add_button(Gtk::Stock::OK, 1);
   create_button = add_button(Gtk::Stock::NEW, 1);
 
   template_button->signal_clicked().connect
-    (safeslot(*this, &Doc_Props_Dialog::update_mode));
+    (slot(*this, &DocPropsDialog::update_mode));
   update_mode();
 
   get_vbox()->show_all();
   get_action_area()->show_all();
 }
 
-void Doc_Props_Dialog::update_mode() {
+DocPropsDialog::~DocPropsDialog() {}
+
+void DocPropsDialog::update_mode() {
   bool active = template_button->get_active();
   format_box->set_sensitive(!active);
   file_entry->set_sensitive(active);
 }
 
-void Doc_Props_Dialog::show_it(Document_View *_view, bool create_new) {
+void DocPropsDialog::show_it(DocumentView *_view, bool create_new) {
   new_document = create_new;
   view = _view;
   if(!new_document) {
-    Document *document = view->get_document();
+    DocRef document = view->get_document();
     if(!document)
       return;
     std::string template_file = document->get_template_file();
@@ -167,13 +173,16 @@ void Doc_Props_Dialog::show_it(Document_View *_view, bool create_new) {
     paper_size->get_entry()->set_text(document->get_paper_name());
 
     create_button->hide(); ok_button->show();
+    cancel_button->grab_default();
     show();
     // Gtk::Entry::set_position doesn't seem to work 
     // unless the entry is shown first
     file_entry->entry.set_text(template_file);
-  } else {
+  } else { // New document
     create_button->show(); ok_button->hide();
+    create_button->grab_default();
     template_button->set_active(true);
+    first_page->set(config.StartPage.values.front()); //Restore default
     show();
   }
 
@@ -184,7 +193,7 @@ void Doc_Props_Dialog::show_it(Document_View *_view, bool create_new) {
 }
 
 
-void Doc_Props_Dialog::on_response(int response_id) {
+void DocPropsDialog::on_response(int response_id) {
   if(response_id == 0) {
     hide();
   } else if(response_id == 1) {
@@ -194,52 +203,55 @@ void Doc_Props_Dialog::on_response(int response_id) {
       : Papers::LANDSCAPE; 
 
     if(template_button->get_active() && file_entry->entry.get_text().empty()) {
-      Error_Dialog::view("No template file was selected");
-      return;
+      throw UserError("No template file was selected",
+		      "Either select a template or uncheck"
+		      " \"Use template\".");
     }
+
     if(new_document) { // Create new document
-      Document *document = 0;
-      try {
-	if(template_button->get_active()) { // Create from template
-	  document = new Document(file_entry->entry.get_text());
-	  document->set_first_page_num(int(first_page->get()));
-	} else {
-	  document = new Document();
-	  document->set_paper_name(paper_size->get_entry()->get_text());
-	  document->set_orientation(orientation);
-	  document->set_doublesided(double_sided_button->get_active());
-	  document->set_first_page_num(int(first_page->get()));
-	}
-	if(view && !view->get_document())
-	  view->set_document(document);
-	else
-	  new Frame_Window("", document);
-	hide();
-      }
-      catch(const Error::Read &e) {
-	delete document;
-	Error_Dialog::view(e.message);
+      DocRef document = Document::null();
+      if(template_button->get_active()){ // Create from template
+	document = Document::create(file_entry->entry.get_text());
+	document->set_first_page_num(int(first_page->get()));
+	//Save template path
+	config.DocTemplatePath.values.front() = file_entry->entry.get_text();
+      } else {
+	document = Document::create();
+	document->set_paper_name(paper_size->get_entry()->get_text());
+	config.PaperName.values.front() = paper_size->get_entry()->get_text();
+	document->set_orientation(orientation);
+	config.Landscape.values.front() = !portrait_button->get_active();
+	document->set_doublesided(double_sided_button->get_active());
+	config.SingleSided.values.front() = single_sided_button->get_active();
+	document->set_first_page_num(int(first_page->get()));
       }
+
+      if(view && !view->get_document())
+	view->set_document(DocMeta(document));
+      else
+	new FrameWindow("", document);
+
+      hide();
     } else { // Modify existing document
-      try {
-	Document *document = view->get_document();
+	DocRef document = view->get_document();
 	if(!document)
 	  return;
 	if(template_button->get_active()) { // create from template
 	  document->set_template(file_entry->entry.get_text());
 	  document->set_first_page_num(int(first_page->get()));
+	  //Save template path
+	  config.DocTemplatePath.values.front() = file_entry->entry.get_text();
 	} else {
 	  document->set_template("");
 	  document->set_paper_name(paper_size->get_entry()->get_text());
+	  config.PaperName.values.front()= paper_size->get_entry()->get_text();
 	  document->set_orientation(orientation);
+	  config.Landscape.values.front() = !portrait_button->get_active();
 	  document->set_doublesided(double_sided_button->get_active());
+	  config.SingleSided.values.front()= single_sided_button->get_active();
 	  document->set_first_page_num(int(first_page->get()));
 	}
 	hide();
-      }
-      catch(const Error::Read &e) {
-	Error_Dialog::view(e.message);
-      }
     }
   }
 }
