@@ -5,7 +5,7 @@
 ///
 #include "widget/dialogwrap.h"
 
-class Document_View;
+class DocumentView;
 namespace Gtk {
   class CheckButton;
   class RadioButton;
@@ -13,30 +13,42 @@ namespace Gtk {
   class VBox;
   class Combo;
 };
-class File_Entry;
+class FileEntry;
 class Spinner;
 
-class Doc_Props_Dialog : public DialogWrap {
+/**
+ * This is a Singleton.
+ */
+class DocPropsDialog : public DialogWrap {
 public:
-  Doc_Props_Dialog();
-  void modify(Document_View *_view) {show_it(_view, false);}
-  void create(Document_View *_view) {show_it(_view, true);};
+  static DocPropsDialog &instance();
+  void modify(DocumentView *_view) {show_it(_view, false);}
+  void create(DocumentView *_view) {show_it(_view, true);};
 
 private:
-  Gtk::CheckButton *template_button;
+  static DocPropsDialog *_instance;  
   Gtk::RadioButton *portrait_button, *landscape_button,
     *single_sided_button, *double_sided_button;
-  Gtk::Button *ok_button, *create_button;
+  Gtk::CheckButton *template_button;
+  Gtk::Button *cancel_button, *ok_button, *create_button;
   Gtk::VBox *format_box;
   Gtk::Combo *paper_size;
-  File_Entry *file_entry;
+  FileEntry *file_entry;
   Spinner *first_page;
   bool new_document;
-  Document_View *view;
+  DocumentView *view;
+
+  DocPropsDialog();
+  // no default constructors:
+  DocPropsDialog(const DocPropsDialog&);
+  void operator = (const DocPropsDialog&);
+  // no destructor
+  ~DocPropsDialog();
 
   void show_raise() {}
   void update_mode();
-  void show_it(Document_View *_view, bool create_new);
+
+  void show_it(DocumentView *_view, bool create_new);
   void on_response(int response_id);
 };
 
