@@ -5,10 +5,15 @@
 ///
 #include "metabase.h"
 
+class FileContext;
+
 class GroupMeta : public MetaBase {
 public:
-  Pagent* load(const xmlpp::Element& node, Group* parent);
-
+  Pagent* load(const xmlpp::Element& node, Group* parent,
+	       const FileContext &context);
+  
+  Viewent::Ref create_viewent(View& view, Pagent& node);
+  
   PropBase* getProp();
 };
 
