@@ -2,24 +2,34 @@
 // Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "imagemeta.h"
-#include "imageframe.h"
+#include "document/imageframe.h"
 #include "propbase.h"
+#include "postscriptviewent.h"
 #include "widget/filesel.h"
 #include "widget/wmisc.h"
 #include <gtkmm/label.h>
 
-Pagent* ImageMeta::load(const xmlpp::Element& node, Group* parent){
-  return new Image_Frame(parent, node);
+Pagent* ImageMeta::load(const xmlpp::Element& node, Group* parent,
+			const FileContext &context)
+{
+  return new ImageFrame(parent, node, context);
 }
 
-// Properties for a EPS image, as represented by Image_Frame.
+Viewent::Ref ImageMeta::create_viewent(View& view, Pagent& node) {
+  Viewent::Ref result(new PostscriptViewent
+		      (view, &dynamic_cast<ImageFrame&>(node)));
+  result->reference();
+  return result;
+}
+
+// Properties for a EPS image, as represented by ImageFrame.
 // Currently just displays the filename.  It should be able to change the file
 // name and possibly display some of the header info from the EPS (title,
 // created by, etc).
-class PropImage : public GenericProp<Image_Frame> {
+class PropImage : public GenericProp<ImageFrame> {
 public:
   PropImage()
-    : GenericProp<Image_Frame>("_EPS"),
+    : GenericProp<ImageFrame>("_EPS"),
      e_fname("Associated File")
     {
       Gtk::Box *line = manage(new Gtk::HBox(false, double_space));
@@ -44,7 +54,7 @@ public:
       object->set_association(e_fname.entry.get_text());
   }
 private:
-  File_Entry e_fname;
+  FileEntry e_fname;
 };
 
 PropBase* ImageMeta::getProp() {
