@@ -3,8 +3,9 @@
 ///
 // Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
-#include "pagent.h"
+#include "document/pagent.h"
 #include "propbase.h"
+#include "viewent.h"
 
 /**
  * An interface to get information about frame kinds.  To invent a new kind of
@@ -12,9 +13,9 @@
  */
 class MetaBase {
 public:
-  // May NOT return 0, but can throw an exception on any error.
-  virtual Pagent* load(const xmlpp::Element& node, Group* parent) = 0;
-
+  virtual Viewent::Ref create_viewent(View& view, Pagent& node) = 0;
+  
+  // MAY return 0.
   virtual PropBase* getProp() = 0;
 };
 
