@@ -2,10 +2,8 @@
 // Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "pagesel.h"
-#include "safeslot.h"
-#include "fileerrors.h"
-#include "page.h"
-#include "document.h"
+#include "document/page.h"
+#include "document/document.h"
 #include "widget/wmisc.h"
 #include <util/stringutil.h>
 #include <util/warning.h>
@@ -21,7 +19,7 @@ void Pagesel::page_selected_action() {
      && (active_item = menu->get_active())) {
       if(Gtk::Label *num = 
 	 dynamic_cast<Gtk::Label*>(active_item->get_child())) {
-	Document *document = document_view.get_document();
+	DocRef document = document_view.get_document();
 	Page *page;
 	if(document && (page = document->get_page(num->get_text())))
 	  document_view.set_current_page_num(page->get_page_num());
@@ -48,7 +46,7 @@ void Pagesel::update() {
   pages.set_menu(dummy); // or else the OptionMenu widget won't notice that 
                          // the real menu has changed
 
-  Document *document = document_view.get_document();
+  DocRef document = document_view.get_document();
   MenuList& menu_list = menu.items();
   menu_list.clear();
 
@@ -90,13 +88,13 @@ void Pagesel::update() {
   pages.set_menu(menu);
 }
 
-Pagesel::Pagesel(Document_View &docview) :
+Pagesel::Pagesel(DocumentView &docview) :
   document_view(docview)
 {
   document_view.current_page_num_changed_signal.connect
-    (safeslot(*this, &Pagesel::update));
+    (slot(*this, &Pagesel::update));
   document_view.document_changed_signal.connect
-    (safeslot(*this, &Pagesel::update));
+    (slot(*this, &Pagesel::update));
 
   left.add(*manage(new Gtk::Arrow(Gtk::ARROW_LEFT, Gtk::SHADOW_NONE)));
   right.add(*manage(new Gtk::Arrow(Gtk::ARROW_RIGHT, Gtk::SHADOW_NONE)));
@@ -108,10 +106,10 @@ Pagesel::Pagesel(Document_View &docview) :
   pack_start(pages);
   pack_start(right);
 
-  left.signal_clicked().connect(safeslot(*this, &Pagesel::prev));
-  right.signal_clicked().connect(safeslot(*this, &Pagesel::next));
+  left.signal_clicked().connect(slot(*this, &Pagesel::prev));
+  right.signal_clicked().connect(slot(*this, &Pagesel::next));
   pages.get_menu()->signal_selection_done().connect
-    (safeslot(*this, &Pagesel::page_selected_action));
+    (slot(*this, &Pagesel::page_selected_action));
 
   show_all();
 }
@@ -135,8 +133,8 @@ namespace {
   const Glib::ustring no_template_string("blank page");
 }
 
-Template_Page_Dialog::Template_Page_Dialog(Gtk::Window &parent, 
-					   Document_View &document_view_):
+TemplatePageDialog::TemplatePageDialog(Gtk::Window &parent, 
+					   DocumentView &document_view_):
   DialogWrap("", parent), 
   document_view(document_view_)
 {
@@ -182,11 +180,11 @@ Template_Page_Dialog::Template_Page_Dialog(Gtk::Window &parent,
   page_list.property_height_request() = 100;
 }
 
-void Template_Page_Dialog::show_it(bool new_page_, int page_num_) {
+void TemplatePageDialog::show_it(bool new_page_, int page_num_) {
   set_title(new_page_ ? "Add Page" : "Template Page");
   tree_model->clear();
   new_page = new_page_; page_num = page_num_;
-  Document *document = document_view.get_document();
+  DocRef document = document_view.get_document();
   if(document) { 
     typedef std::list<std::string> Strings;
     Strings tmp = document->get_template_pages();
@@ -208,11 +206,11 @@ void Template_Page_Dialog::show_it(bool new_page_, int page_num_) {
   show();
 }
 
-void Template_Page_Dialog::on_response(int response_id) {
+void TemplatePageDialog::on_response(int response_id) {
   switch(response_id) {
   case Gtk::RESPONSE_OK:
     {
-      Document *document = document_view.get_document();
+      DocRef document = document_view.get_document();
       if(new_page && document) {
 	std::string page_name = "";
 	Glib::RefPtr<Gtk::TreeSelection> selection = page_list.get_selection();
@@ -222,23 +220,19 @@ void Template_Page_Dialog::on_response(int response_id) {
 	  page_name = Glib::ustring(row[columns.col_name]);
 	}
 	
-	try {
 	  if(!page_name.empty() && page_name != no_template_string
 	     && document->get_template()) {
 	    Page *t_page = document->get_template()->get_page(page_name);
 	    if(!t_page) {
-	      Error_Dialog::view("Template page \""
-				 + page_name
-				 + "\" not found");
+	      // There should only be existing template pages in the list
+	      throw std::logic_error("Template page \""
+				     + page_name
+				     + "\" not found");
 	      return;
 	    }
 	    document->new_page(page_num, t_page); //problem here
 	  } else
 	    document->new_page(page_num);
-	} catch(const Error::Read &e) {
-	  Error_Dialog::view(e.message);
-	  return;
-	}
       }
     }
     break;
