@@ -2,7 +2,6 @@
 // Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "pixbuftransformator.h"
-#include "safeslot.h"
 #include <util/warning.h>
 #include <gtkmm/main.h>
 #include <algorithm>		// just min/max
@@ -39,7 +38,7 @@ PixbufTransformator::PixbufTransformator(Glib::RefPtr<const Gdk::Pixbuf> src,
   d_pix  = (inv.transform(view.scr2pt(Gdk::Point(min_x + 1, min_y))) - lstart);
   d_line = (inv.transform(view.scr2pt(Gdk::Point(min_x, min_y + 1))) - lstart);
   
-  Glib::signal_idle().connect(safeslot(*this, &PixbufTransformator::workLine));
+  Glib::signal_idle().connect(slot(*this, &PixbufTransformator::workLine));
 }
 
 PixbufTransformator::~PixbufTransformator() {}
