@@ -6,6 +6,7 @@
 #include "imagemeta.h"
 #include "rastermeta.h"
 #include "textmeta.h"
+#include "pagemeta.h"
 
 PptCore core;
 
@@ -16,6 +17,7 @@ PptCore::PptCore() {
   meta["image"] = new ImageMeta;
   meta["raster"] = new RasterMeta;
   meta["text"] = new TextMeta;
+  meta["page"] = new PageMeta;
 }
 
 MetaBase* PptCore::getMeta(const std::string& type) {
