@@ -4,6 +4,7 @@
 #include "printdialog.h"
 #include "widget/subpanel.h"
 #include "widget/wmisc.h"
+#include "widget/usererror.h"
 #include <fstream>
 
 #include <gtkmm/table.h>
@@ -11,20 +12,17 @@
 #include <gtkmm/stock.h>
 #include <gtkmm/sizegroup.h>
 
-#include <util/warning.h>
-#include <util/filesys.h>
-#include <util/os.h>
+#include "util/warning.h"
+#include "util/filesys.h"
+#include "util/os.h"
+#include "util/tempfile.h"
 
-#include "globals.h"
 #include "config.h"
-#include "fileerrors.h"
 #include "docview.h"
-#include "safeslot.h"
-#include "processman.h"
-#include "document.h"
+#include "document/document.h"
 
-Print_Dialog::Print_Dialog(Gtk::Window &parent, 
-			   Document_View &_document_view):
+PrintDialog::PrintDialog(Gtk::Window &parent, 
+			   DocumentView &_document_view):
   DialogWrap("Print", parent), 
   using_button("Print _using:", true), file_button("Print _to file:", true),
   all_button("_All", true), current_button("Cu_rrent", true), 
@@ -99,22 +97,22 @@ Print_Dialog::Print_Dialog(Gtk::Window &parent,
   using_button.set_active(true);
 
   using_button.signal_clicked().connect
-    (safeslot(*this, &Print_Dialog::update));
+    (slot(*this, &PrintDialog::update));
   // If there are only two buttons in a group, you only need to connect one.
   // If there are more, you need to connect them all. That is annoying.
   all_button.signal_clicked().connect
-    (safeslot(*this, &Print_Dialog::update));
+    (slot(*this, &PrintDialog::update));
   current_button.signal_clicked().connect
-    (safeslot(*this, &Print_Dialog::update));
+    (slot(*this, &PrintDialog::update));
   from_button.signal_clicked().connect
-    (safeslot(*this, &Print_Dialog::update));
+    (slot(*this, &PrintDialog::update));
 
   add_button(Gtk::Stock::CANCEL, 0);
-  add_button(Gtk::Stock::PRINT, 1);
+  add_button(Gtk::Stock::PRINT, 1)->grab_default();
 }
 
-void Print_Dialog::show_it() {
-  Document *document = document_view.get_document();
+void PrintDialog::show_it() {
+  DocRef document = document_view.get_document();
   if(!document)
     return;
   int first = document->get_first_page_num();
@@ -128,22 +126,23 @@ void Print_Dialog::show_it() {
   show();
   // Gtk::Entry::set_position doesn't seem to work 
   // unless the entry is shown first
-  std::string filename = document->get_filename();
+  const std::string &filename = 
+    document_view.get_document_meta().get_filename();
   if(filename.empty())     // the document has not been saved 
     file_entry.entry.set_text("pptout.ps");
   else
     file_entry.entry.set_text(no_suffix(filename) + ".ps");
 }
 
-void Print_Dialog::on_response(int response_id) {
-  // TODO: setting the cursor has no effect until the function exits
+void PrintDialog::on_response(int response_id) {
+  /// \todo setting the cursor has no effect until the function exits
   //  Glib::RefPtr<Gdk::Window> window = get_window();
   if(response_id == 0) {
     restore_state();
     hide();
   } else if(response_id == 1) { 
     try { 
-      Document *document = document_view.get_document();
+      DocRef document = document_view.get_document();
       if(document) {
 	int first = document->get_first_page_num();
 	int last = first + document->get_num_of_pages() - 1;
@@ -153,16 +152,19 @@ void Print_Dialog::on_response(int response_id) {
 	  first = int(from_spinner.get());
 	  last = int(to_spinner.get());
 	  if(last < first)
-	    throw Error::Print("\"From\" page number must be lower\n"
-			       "than \"To\" page number");
+	    throw UserError("Bad page interval",
+			    "\"From\" page number must be lower\n"
+			    "than \"To\" page number");
 	  // We could make this error impossible to cause, 
 	  // but I don't like putting leash and collar on the user.
 	}
 	// else all_button is active
 	if(file_button.get_active()) {
 	  std::ofstream out(file_entry.entry.get_text().c_str());
-	  if(!out) throw Error::Print("Could not print to file:\n"
-				      + file_entry.entry.get_text());
+	  if(!out) throw UserError("Failed to open file for printing:\n"
+				   + file_entry.entry.get_text(),
+				   "Check that you have permission "
+				   "to write to this file");
 	  // 	  window->set_cursor(Gdk::WATCH);
 	  document->print(out, first, last, 
 			  eps_button.get_active(),
@@ -170,18 +172,20 @@ void Print_Dialog::on_response(int response_id) {
 			  gray_button.get_active());
 	  //	  window->set_cursor();
 	} else {
-	  Tempfile tempfile(process_manager);
+	  Tempfile tempfile;
 	  std::ofstream out(tempfile.get_filename().c_str());
 	  if(!out) 
-	    throw Error::Print("Could not print to file:\n"
-			       + tempfile.get_filename());
+	    throw UserError("Failed to open temporary file for printing:\n"
+			    + tempfile.get_filename(),
+			    "Check that you have permission "
+			    "to write to this file");
 	  //	  window->set_cursor(Gdk::WATCH);
 	  document->print(out, first, last, 
 			  eps_button.get_active(),
 			  fonts_button.get_active(),
 			  gray_button.get_active());
 	  //	  window->set_cursor();
-	  std::string stdout, stderr;
+	  std::string stdout_data, stderr_data;
 	  int status;
 	  std::string command = using_entry.get_text() 
 	    + " < " + tempfile.get_filename();
@@ -189,29 +193,30 @@ void Print_Dialog::on_response(int response_id) {
 	  try {
 	    debug << command << std::endl;
 	    Glib::spawn_command_line_sync(command,
-					  &stdout, &stderr, &status);
+					  &stdout_data, &stderr_data, &status);
 	    debug << status << std::endl;
-	    debug << stderr << std::endl;
-	  } catch(Glib::SpawnError e) {
-	    throw Error::Print("Failed to run: "
-			       + using_entry.get_text() + "\n\n"
-			       + e.what());
+	    debug << stderr_data << std::endl;
+	  } catch(const Glib::SpawnError &e) {
+	    // Glib::SpawnError is not a std::exception
+	    throw UserError("Failed to run: "
+			    + using_entry.get_text(),
+			    e.what());
 	  }
 	  if(status != 0)
-	    throw Error::Print("Could not print using: "
-			       + using_entry.get_text() + "\n\n"
-			       + stderr);
+	    throw UserError("Failed to print using: "
+			    + using_entry.get_text(),
+			    stderr_data);
 	}
 	hide();
       }
-    } catch(std::runtime_error e) {
+    } catch(...) {
       //      window->set_cursor(); // restore normal cursor
-      Error_Dialog::view(e.what());
+      throw;
     }
   }
 }
 
-void Print_Dialog::save_state() {
+void PrintDialog::save_state() {
   saved_using_text = using_entry.get_text();
   saved_file_text = file_entry.entry.get_text();
   saved_file_not_using = file_button.get_active();
@@ -220,7 +225,7 @@ void Print_Dialog::save_state() {
   saved_fonts = fonts_button.get_active();
 }
 
-void Print_Dialog::restore_state() {
+void PrintDialog::restore_state() {
   using_entry.set_text(saved_using_text);
   file_entry.entry.set_text(saved_file_text);
   file_button.set_active(saved_file_not_using);
@@ -229,7 +234,7 @@ void Print_Dialog::restore_state() {
   fonts_button.set_active(saved_fonts);
 }
 
-void Print_Dialog::update() {
+void PrintDialog::update() {
   using_entry.set_sensitive(using_button.get_active());
   file_entry.set_sensitive(file_button.get_active());
   eps_button.set_sensitive(current_button.get_active());
