@@ -11,11 +11,11 @@
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/entry.h>
 
-class Document_View;
+class DocumentView;
 
-class Print_Dialog : public DialogWrap {
+class PrintDialog : public DialogWrap {
 public:
-  Print_Dialog(Gtk::Window &parent, Document_View &_document_view);
+  PrintDialog(Gtk::Window &parent, DocumentView &_document_view);
   void show_it();
 
 private:
@@ -24,8 +24,8 @@ private:
   Gtk::CheckButton eps_button, fonts_button, gray_button;
   Gtk::Entry using_entry;
   Spinner from_spinner, to_spinner;
-  Document_View &document_view; // document_view keeps record of the document
-  File_Entry file_entry;
+  DocumentView &document_view; // document_view keeps record of the document
+  FileEntry file_entry;
   Filesel *filesel;
 
   std::string saved_file_text, saved_using_text;
