@@ -5,7 +5,7 @@
 ///
 #include <gtkmm/box.h>
 #include <gtkmm/label.h>
-#include "pagent.h"
+#include "document/pagent.h"
 
 // Base class for the different property sets.
 // PropertiesDialog displays one PropBase at a time, through a Gtk Notebook.
