@@ -15,11 +15,12 @@
 #include <gtkmm/stock.h>
 #include <gtkmm/sizegroup.h>
 #include <algorithm>
-#include "safeslot.h"
 #include "pptcore.h"
 #include "widget/spinner.h"
-#include "basicframe.h"
+#include "document/basicframe.h"
 #include "lengthunits.h"
+#include "config.h"
+
 
 // The basic properties that apply to all Pagent's.
 // Currently that means some kind of name, and the position and size of the
@@ -30,17 +31,17 @@ public:
   // -----------------------------------------
   // | left:  | "left"  | width:  | "width"  |
   // | right: | "right" | height: | "height" |
-  PropBasic()
+  PropBasic(const std::string &default_unit)
     :PropBase("_Basic"), lock(false), object(0),
-     e_left(0, true, &length_units), e_bottom(0, true, &length_units), 
-     e_width(0, true, &length_units), e_height(0, true, &length_units), 
+     e_left(0, true, &length_units, default_unit),
+     e_bottom(0, true, &length_units, default_unit), 
+     e_width(0, true, &length_units, default_unit),
+     e_height(0, true, &length_units, default_unit), 
      e_rotate(0, true, &angle_units), 
-     e_margin(0, true, &length_units),
+     e_margin(0, true, &length_units, default_unit),
      c_flow("Text avoids object", 0), c_locked("Locked", 0)
-
-    {
+  {
       Gtk::Label *label;
-      e_name.set_editable(false);
       Gtk::Box *line = manage(new Gtk::HBox(false, double_space));
       line->pack_start(*(label = manage(new Gtk::Label("Object _name:", 
 						       0.0, 0.5, true))),
@@ -98,7 +99,7 @@ public:
       flow_box->pack_start(c_locked, Gtk::PACK_SHRINK, triple_space);
       flow_box->pack_start(c_flow, Gtk::PACK_SHRINK, 0);
       c_flow.signal_toggled().connect
-	(safeslot(*this, &PropBasic::on_c_flow_toggle));
+	(slot(*this, &PropBasic::on_c_flow_toggle));
       flow_box->pack_start(e_margin, Gtk::PACK_SHRINK, 0);
       pack_start(*flow_box, Gtk::PACK_SHRINK);
 
@@ -119,9 +120,9 @@ public:
     object = pagent;
     if(object) {
       geometry_changed_connection = object->geometry_changed_signal.connect
-	(safeslot(*this, &PropBasic::on_geometry_changed));
+	(slot(*this, &PropBasic::on_geometry_changed));
       props_changed_connection = object->props_changed_signal.connect
-	(safeslot(*this, &PropBasic::on_props_changed));
+	(slot(*this, &PropBasic::on_props_changed));
     }
     set_sensitive(object);
     if(is_visible())
@@ -154,22 +155,21 @@ public:
   }
   void apply() {
     lock = true; // don't update while applying
+    
+    object->set_name(e_name.get_text());
+    object->set_lock(c_locked.get_active());
+    object->set_obstacle_margin(e_margin.get());
+    object->set_flow_around(c_flow.get_active());
 
-    object->set_lock(c_locked.get_active(), true); // push_undo
-    object->set_obstacle_margin(e_margin.get(), true); // push_undo
-    object->set_flow_around(c_flow.get_active(), true); // push_undo
-
-    object->set_rotation(Matrix::deg2rad(e_rotate.get()), true); // push_undo
-    object->set_translation(Vector(e_left.get(), e_bottom.get()), 
-			    true); // push_undo
+    object->set_rotation(Matrix::deg2rad(e_rotate.get()));
+    object->set_translation(Vector(e_left.get(), e_bottom.get()));
 
     // resize if possible, scale otherwise
     if(object->is_resizable())
-      object->set_size(e_width.get(), e_height.get(), true); // push_undo
+      object->set_size(e_width.get(), e_height.get());
     else {
       object->set_scaling(e_width.get() / object->get_width(), 
-			  e_height.get() / object->get_height(), 
-			  true); // push_undo
+			  e_height.get() / object->get_height());
     }
 
     object->ready_to_draw_signal(object);
@@ -189,15 +189,23 @@ private:
 
 // - - - - back to the actual PropertiesDialog implementation - - - -
 
+PropertiesDialog *PropertiesDialog::_instance = 0;
+
+PropertiesDialog &PropertiesDialog::instance() {
+  if(!_instance)
+    _instance = new PropertiesDialog();
+  return *_instance;
+}
+
 PropertiesDialog::PropertiesDialog()
   : DialogWrap("Object Properties"),
-  document(0),
-  apply_button(Gtk::Stock::APPLY), close_button(Gtk::Stock::CLOSE)
+    document(0),
+    apply_button(Gtk::Stock::APPLY), close_button(Gtk::Stock::CLOSE)
 {
   //  set_border_width(border_width);
   get_vbox()->pack_start(book);
 
-  PropBase* prop = new PropBasic;
+  PropBase* prop = new PropBasic(config.LengthUnit.values.front());
   pages.push_back(prop);
   book.append_page(*prop, prop->getLabel());
   for(PptCore::MetaMap::const_iterator
@@ -211,15 +219,17 @@ PropertiesDialog::PropertiesDialog()
   get_action_area()->pack_start(apply_button, false, false);
   get_action_area()->pack_start(close_button, false, false);
   apply_button.signal_clicked().connect
-    (safeslot(*this, &PropertiesDialog::apply));
+    (slot(*this, &PropertiesDialog::apply));
   close_button.signal_clicked().connect
-    (safeslot(*this, &PropertiesDialog::hide));
+    (slot(*this, &PropertiesDialog::hide));
 
   // listen to selection change signals:
   Document::selection_changed_signal.connect
     (slot(*this, &PropertiesDialog::select_change));
 }
 
+PropertiesDialog::~PropertiesDialog() {}
+
 void
 PropertiesDialog::show_raise() {
   show_all();
@@ -235,9 +245,8 @@ PropertiesDialog::apply() {
 }
 
 void
-PropertiesDialog::set_document(Document *document_)
-{
-  document=document_;
+PropertiesDialog::set_document(DocRef document_) {
+  document = document_;
   update();
 }
 
@@ -255,13 +264,13 @@ PropertiesDialog::update() {
 
   apply_button.set_sensitive(pagent);
 
-  for(std::vector<PropBase*>::const_iterator i=pages.begin();
-      i!=pages.end(); ++i)
+  for(std::vector<PropBase*>::const_iterator i = pages.begin();
+      i != pages.end(); ++i)
     (*i)->setObject(pagent);
 }
 
 void
-PropertiesDialog::select_change(Document* doc) {
-  if(doc==document)
+PropertiesDialog::select_change(DocRef doc) {
+  if(document == doc)
     update();
 }
