@@ -3,8 +3,8 @@
 ///
 // Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
-#include "document.h"
-#include <widget/dialogwrap.h>
+#include "document/document.h"
+#include "widget/dialogwrap.h"
 #include <gtkmm/notebook.h>
 #include <gtkmm/button.h>
 #include <vector>
@@ -12,25 +12,33 @@
 class PropBase;
 
 /**
- * A dialog displaying properties of the selected objeckt.  It will listen
- * for selection events, so when the user selects a new object, the existing
+ * A dialog displaying properties of the selected object.  It will listen
+ * for selection signals, so when the user selects a new object, the existing
  * dialog will show properties for that object.
+ * This is a Singleton.
  */
 class PropertiesDialog : public DialogWrap {
 public:
-  PropertiesDialog();
+  static PropertiesDialog &instance();
   
   void show_raise();		// Make sure this dialog is visible
   void apply();			// Apply changes done in this dialog
   
-  void *get_document() const
-  {return document;}
-  void set_document(Document *document_);
+  DocRef get_document() const { return document; }
+  void set_document(DocRef document_);
   
 private:
-  void select_change(Document* doc);		// signal listener
+  static PropertiesDialog *_instance;
+  void select_change(DocRef doc);		// signal listener
   void update();
-  Document *document;
+  DocRef document;
+
+  PropertiesDialog();
+  // no default constructors:
+  PropertiesDialog(const PropertiesDialog&);
+  void operator = (const PropertiesDialog&);
+  // no destructor
+  ~PropertiesDialog();
 
   Gtk::Notebook book;
   std::vector<PropBase*> pages;
