@@ -2,7 +2,8 @@
 // Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "rastermeta.h"
-#include "rasterframe.h"
+#include "document/rasterframe.h"
+#include "rasterviewent.h"
 #include "widget/spinner.h"
 #include "widget/filesel.h"
 #include "widget/subpanel.h"
@@ -10,15 +11,23 @@
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/separator.h>
 #include <gtkmm/sizegroup.h>
-#include "safeslot.h"
 #include <util/warning.h>
 
-Pagent* RasterMeta::load(const xmlpp::Element& node, Group* parent){
-  return new Raster_Frame(parent, node);
+Pagent* RasterMeta::load(const xmlpp::Element& node, Group* parent,
+			 const FileContext &context)
+{
+  return new RasterFrame(parent, node, context);
+}
+
+Viewent::Ref RasterMeta::create_viewent(View& view, Pagent& node) {
+  Viewent::Ref result(new RasterViewent
+		      (view, &dynamic_cast<RasterFrame&>(node)));
+  result->reference();
+  return result;
 }
 
 namespace {
-  class PropRaster : public GenericProp<Raster_Frame> {
+  class PropRaster : public GenericProp<RasterFrame> {
   public:
     PropRaster();
     
@@ -31,7 +40,7 @@ namespace {
     float last_x, last_y;
     bool use_aspect;
     
-    File_Entry e_fname;
+    FileEntry e_fname;
     Spinner e_ppix, e_ppiy;
     Gtk::ToggleButton b_ppic;
     Gtk::HSeparator hsep;
@@ -43,7 +52,7 @@ PropBase* RasterMeta::getProp() {
 }
 
 PropRaster::PropRaster()
-  :GenericProp<Raster_Frame>("_Raster"), use_aspect(false),
+  :GenericProp<RasterFrame>("_Raster"), use_aspect(false),
    e_fname("Associated File"),  b_ppic("}", Gtk::JUSTIFY_RIGHT)
 {
   Gtk::Label *label;
@@ -89,13 +98,12 @@ PropRaster::PropRaster()
 
   pack_start(*rezpanel, Gtk::PACK_SHRINK);
   
-  // Todo: Safeslot * 3 here!
   e_ppix.signal_changed.connect
     (bind(slot(*this, &PropRaster::change_val), true));
   e_ppiy.signal_changed.connect
     (bind(slot(*this, &PropRaster::change_val), false));
   b_ppic.signal_toggled().connect
-    (safeslot(*this, &PropRaster::toggleAspect));
+    (slot(*this, &PropRaster::toggleAspect));
   b_ppic.set_active(true);
   set_sensitive(false);
   update();
@@ -122,7 +130,7 @@ void PropRaster::apply() {
 void PropRaster::toggleAspect() {
   use_aspect = b_ppic.get_active();
   if(object && use_aspect) {
-    e_ppiy.set(e_ppix.get());	// Todo: * object->getAspectRatio()
+    e_ppiy.set(e_ppix.get());	/// \todo * object->getAspectRatio()
   }
 }
 
@@ -136,12 +144,12 @@ void PropRaster::change_val(bool x_active) {
       const float x(e_ppix.get()), y(e_ppiy.get());
       if(x_active) {
 	if(x != last_x) {
-	  last_x = x; last_y = x; // Todo: * object->getAspectRatio()
+	  last_x = x; last_y = x; /// \todo * object->getAspectRatio()
 	  e_ppiy.set(last_y);
 	}
       } else {
 	if(y != last_y) {
-	  last_y = y; last_x = y; // Todo: / object->getAspectRatio()
+	  last_y = y; last_x = y; /// \todo / object->getAspectRatio()
 	  e_ppix.set(last_x);
 	}
       }
