@@ -11,7 +11,7 @@ namespace PS {
 
   std::string EncodeFilterCascade::decode_command() const {
     std::string cmd = "";
-    for(Filter_Sequence::const_iterator i = sequence.begin(); 
+    for(FilterSequence::const_iterator i = sequence.begin(); 
 	i != sequence.end();
 	i++)
       cmd += (*i)->decode_command() + " ";
@@ -22,7 +22,7 @@ namespace PS {
     EncodeFilter::begin(out_);
     // Run begin only for the stream that is actually going to 
     // write to the stream:
-    Filter_Sequence::iterator i = sequence.begin();
+    FilterSequence::iterator i = sequence.begin();
     if(sequence.size() > 0)
       (*i)->begin(out_);
     while(++i != sequence.end())
@@ -33,9 +33,9 @@ namespace PS {
 				  unsigned long count, 
 				  bool flush)
   {
-    Filter_Sequence::iterator i = sequence.end(), j;
+    FilterSequence::iterator i = sequence.end(), j;
     if(i == sequence.begin()) // no filters
-      return; // Todo: should really write raw data to out
+      return; /// \todo should really write raw data to out
     j = --i; j--;
     if(i == sequence.begin()) { // only one filter
       (*i)->write(data, count, flush);
@@ -47,12 +47,12 @@ namespace PS {
     while(j != sequence.begin()) {
       i--;
       (*i)->filter(data1, count1, data2, count2, flush);      
-      delete data1;
+      delete[] data1;
       data1 = data2;  count1 = count2;
       j--;
     }
     (*j)->write(data1, count1, flush);
-    delete data1;
+    delete[] data1;
   }
 
   // ASCIIHexEncodeFilter
@@ -70,7 +70,7 @@ namespace PS {
       (*out) << std::setw(2) << int(data[i]);
       line_width += 2;
       if(line_width >= max_line_width) {
-	(*out) << std::endl;
+	(*out) << '\n';
 	line_width = 0;
       }
     }
@@ -115,7 +115,7 @@ namespace PS {
       (*out) << "z";
       line_width++;
       if(line_width >= max_line_width) {
-	(*out) << std::endl;
+	(*out) << '\n';
 	line_width = 0;
       }
       return 1;
@@ -150,7 +150,7 @@ namespace PS {
       out->put(out_chunk[i] + 33); // 33 is the ASCII code for '!'
       line_width++;
       if(line_width >= max_line_width) {
-	(*out) << std::endl;
+	(*out) << '\n';
 	line_width = 0;
       }
     }
@@ -174,7 +174,7 @@ namespace PS {
     }
 
     // encode
-    while(offset + 4 <= count) { // Todo: watch out for integer overflow
+    while(offset + 4 <= count) { /// \todo watch out for integer overflow
       write_chunk(&data[offset]);
       offset += 4;
     }
@@ -207,7 +207,7 @@ namespace PS {
 				   unsigned long &count_out,
 				   bool flush)
   {
-    // Todo: ...
+    /// \todo ...
     data_out = new unsigned char[1];
     count_out = 1;
   }
@@ -228,7 +228,7 @@ namespace PS {
     unsigned char *data_out;
     filter(data, count, data_out, count_out, flush);
     out->write(reinterpret_cast<const char*>(data_out), count_out);
-    delete data_out;
+    delete[] data_out;
   }
 
   void RunLengthEncodeFilter::flush_buffer() {
