@@ -19,8 +19,14 @@ public:
   /** Wait for the barrier to become open. */
   void wait();
   
-  /** Open the barrier, all current and future {wait}s are returned. */
+  /** 
+   * Open the barrier, all current and future {wait}s are
+   * returned. Opening a Barrier that is already open is a no-op.
+   */
   void open();
+
+  /** Get current state of the {Barrier}.  This method is non-blocking. */
+  bool get_open() { return is_open; }
   
   /**
    * Close the barrier so it can be used again.
