@@ -7,9 +7,9 @@
 
 // Aliases for std::cerr that can be turned off.
 
-struct cerr_Alias
+struct cerrAlias
 {
-  explicit cerr_Alias(bool a) : active(a) {}
+  explicit cerrAlias(bool a) : active(a) {}
 
   bool active;
 
@@ -29,12 +29,12 @@ private:
 };
 
 // serious stuff, should not be turned off
-extern cerr_Alias warning;
+extern cerrAlias warning;
 
 // for people who want to know what happens behind the scenes
-extern cerr_Alias verbose;
+extern cerrAlias verbose;
 
 // debug stuff that means nothing to the user
-extern cerr_Alias debug;
+extern cerrAlias debug;
 
 #endif
